Module types

Module types 

Area types and traits

Defines the different types of areas and their associated traits.

Structs

Area
An area represents a rectangular region on a page
TextDecoration
Text decoration values
TraitSet
Rendering traits for an area

Enums

AreaContent
Content stored in an area
AreaType
Types of areas in the area tree
BorderStyle
Border style values (XSL-FO and CSS compatible)
Direction
Text direction values
DisplayAlign
Display alignment (vertical alignment within a block area)
FontStretch
Font stretch values
FontStyle
Font style values
FontVariant
Font variant
Span
Span values for fo:block column spanning
TextTransform
Text transformation mode
WritingMode
Writing mode values for XSL-FO