Module table

Module table 

Table layout algorithm

Implements fixed and auto table layout modes for positioning cells in a grid.

Re-exports

pub use types::BorderCollapse;
pub use types::CellCollapsedBorders;
pub use types::CollapsedBorder;
pub use types::ColumnInfo;
pub use types::ColumnWidth;
pub use types::GridCell;
pub use types::TableLayout;
pub use types::TableLayoutMode;

Modules

border
Border conflict resolution for the collapsed border model
column
Column width calculation algorithms (fixed and auto layout)
grid
Grid creation, cell placement, and table-level layout
types
Table layout types: enums, structs for table, column, cell, and border data