pub struct ColumnInfo {
pub width_spec: ColumnWidth,
pub computed_width: Length,
pub min_width: Length,
pub max_width: Length,
}Expand description
Information about a table column
Used in auto layout algorithm to track column width constraints.
Fields
width_spec: ColumnWidthColumn width specification
computed_width: LengthComputed width (after layout)
min_width: LengthMinimum content width Smallest width that prevents content overflow
max_width: LengthMaximum content width Preferred width without any line breaking
Implementations
Sourceimpl ColumnInfo
impl ColumnInfo
Sourcepub fn new(width_spec: ColumnWidth) -> Self
pub fn new(width_spec: ColumnWidth) -> Self
Create a new ColumnInfo with the given width specification
Sourcepub fn with_widths(
width_spec: ColumnWidth,
min_width: Length,
max_width: Length,
) -> Self
pub fn with_widths( width_spec: ColumnWidth, min_width: Length, max_width: Length, ) -> Self
Create a ColumnInfo with explicit min/max widths