Area types and traits
Defines the different types of areas and their associated traits.
Structs
- Area
- An area represents a rectangular region on a page
- Text
Decoration - Text decoration values
- Trait
Set - Rendering traits for an area
Enums
- Area
Content - Content stored in an area
- Area
Type - Types of areas in the area tree
- Border
Style - Border style values (XSL-FO and CSS compatible)
- Direction
- Text direction values
- Display
Align - Display alignment (vertical alignment within a block area)
- Font
Stretch - Font stretch values
- Font
Style - Font style values
- Font
Variant - Font variant
- Span
- Span values for fo:block column spanning
- Text
Transform - Text transformation mode
- Writing
Mode - Writing mode values for XSL-FO