pub struct StreamingLayoutEngine { /* private fields */ }Expand description
Streaming layout engine that yields pages one at a time
Implementations
Sourceimpl StreamingLayoutEngine
impl StreamingLayoutEngine
Sourcepub fn with_config(config: StreamingConfig) -> Self
pub fn with_config(config: StreamingConfig) -> Self
Create a new streaming layout engine with custom configuration
Sourcepub fn layout_streaming<'a, 'b>(
&'a self,
fo_tree: &'b FoArena<'b>,
) -> StreamingLayoutIterator<'a, 'b> ⓘ
pub fn layout_streaming<'a, 'b>( &'a self, fo_tree: &'b FoArena<'b>, ) -> StreamingLayoutIterator<'a, 'b> ⓘ
Layout an FO tree in streaming mode, yielding one page at a time
This method returns an iterator that produces one AreaTree per page. Each AreaTree contains only the areas for that single page and can be immediately rendered and discarded to minimize memory usage.